--	**********    PREPARE    **********

USE master;
GO

-- drop database, if needed
IF DATABASEPROPERTYEX('test', 'Version') IS NOT NULL
BEGIN
	ALTER DATABASE [test]
	SET SINGLE_USER 
	WITH ROLLBACK IMMEDIATE;

	DROP DATABASE [test];
END
GO

-- create test database
CREATE DATABASE [test]
ON  PRIMARY 
(	NAME = N'test', 
	FILENAME = N'C:\Data\test.mdf', 
	SIZE = 5120KB, 
	FILEGROWTH = 1024KB 
)
LOG ON 
(	NAME = N'test_log', 
	FILENAME = N'C:\Data\test_log.ldf', 
	SIZE = 1024KB, 
	MAXSIZE = 2048KB, 
	FILEGROWTH = 512KB 
)
GO

-- switch to simple recovery model
ALTER DATABASE [test] SET RECOVERY SIMPLE;
GO

--	**********    Viewing INSERT, UPDATE, DELETE    **********

USE [test];
GO

CREATE TABLE [dbo].[Messages](
	[MessageId] [int] IDENTITY(1,1) NOT NULL,
	[MessageText] [nchar](2000) NOT NULL
) ON [PRIMARY]
GO

-- do checkpoint to truncate log
CHECKPOINT;

-- insert first record
-- look at allocation events
INSERT INTO Messages (MessageText)
VALUES (N'bla-bla-bla');
GO

SELECT * FROM fn_dblog(null, null);

-- do checkpoint to truncate log
CHECKPOINT;

-- insert second record
INSERT INTO Messages (MessageText)
VALUES (N'AAAAA');
GO

SELECT * FROM fn_dblog(null, null);

-- update record
UPDATE Messages
SET MessageText = N'BBBBB'
WHERE MessageText = N'AAAAA';
GO

SELECT * FROM fn_dblog(null, null);

-- delete record
DELETE FROM Messages
WHERE MessageText = N'BBBBB';
GO

SELECT * FROM fn_dblog(null, null);
